@@ -10,17 +10,18 @@ import sys
 import sysconfig
 import textwrap
 from pathlib import Path
-from typing import TYPE_CHECKING, Generator
+from typing import TYPE_CHECKING, Any
 
 from . import __version__
 from ._logging import logger
 from ._shutil import Run
 from .errors import CMakeConfigError, CMakeNotFoundError, FailedLiveProcessError
-from .program_search import best_program, get_cmake_programs
+from .program_search import Program, best_program, get_cmake_program, get_cmake_programs
 
 if TYPE_CHECKING:
-    from collections.abc import Mapping, Sequence
+    from collections.abc import Generator, Iterable, Mapping, Sequence
 
+    from packaging.specifiers import SpecifierSet
     from packaging.version import Version
 
     from ._compat.typing import Self
@@ -42,13 +43,23 @@ class CMake:
 
     @classmethod
     def default_search(
-        cls, *, minimum_version: Version | None = None, module: bool = True
+        cls,
+        *,
+        version: SpecifierSet | None = None,
+        module: bool = True,
+        env: Mapping[str, Any] | None = None,
     ) -> Self:
-        candidates = get_cmake_programs(module=module)
-        cmake_program = best_program(candidates, minimum_version=minimum_version)
+        env = env or {}
+        cmake_executable = env.get("CMAKE_EXECUTABLE", "")
+        candidates: Iterable[Program] = (
+            [get_cmake_program(Path(cmake_executable))]
+            if cmake_executable
+            else get_cmake_programs(module=module)
+        )
+        cmake_program = best_program(candidates, version=version)
 
         if cmake_program is None:
-            msg = f"Could not find CMake with version >= {minimum_version}"
+            msg = f"Could not find CMake with version {version}"
             raise CMakeNotFoundError(msg)
         if cmake_program.version is None:
             msg = "CMake version undetermined @ {program.path}"
@@ -85,28 +96,25 @@ class CMaker:
             raise CMakeConfigError(msg)
 
         # If these were the same, the following check could wipe the source directory!
-        if self.build_dir.resolve() == self.source_dir.resolve():
-            msg = "build directory must be different from source directory"
-            raise CMakeConfigError(msg)
+        if self.build_dir.resolve() != self.source_dir.resolve():
+            skbuild_info = self.build_dir / ".skbuild-info.json"
+            # If building via SDist, this could be pre-filled, so delete it if it exists
+            with contextlib.suppress(FileNotFoundError):
+                with skbuild_info.open("r", encoding="utf-8") as f:
+                    info = json.load(f)
 
-        skbuild_info = self.build_dir / ".skbuild-info.json"
-        # If building via SDist, this could be pre-filled, so delete it if it exists
-        with contextlib.suppress(FileNotFoundError):
-            with skbuild_info.open("r", encoding="utf-8") as f:
-                info = json.load(f)
+                cached_source_dir = Path(info["source_dir"])
+                if cached_source_dir.resolve() != self.source_dir.resolve():
+                    logger.warning(
+                        "Original src {} != {}, wiping build directory",
+                        cached_source_dir,
+                        self.source_dir,
+                    )
+                    shutil.rmtree(self.build_dir)
+                    self.build_dir.mkdir()
 
-            cached_source_dir = Path(info["source_dir"])
-            if cached_source_dir.resolve() != self.source_dir.resolve():
-                logger.warning(
-                    "Original src {} != {}, wiping build directory",
-                    cached_source_dir,
-                    self.source_dir,
-                )
-                shutil.rmtree(self.build_dir)
-                self.build_dir.mkdir()
-
-        with skbuild_info.open("w", encoding="utf-8") as f:
-            json.dump(self._info_dict(), f, indent=2)
+            with skbuild_info.open("w", encoding="utf-8") as f:
+                json.dump(self._info_dict(), f, indent=2)
 
     def _info_dict(self) -> dict[str, str]:
         """
@@ -170,9 +178,6 @@ class CMaker:
         if self.init_cache_file.is_file():
             yield f"-C{self.init_cache_file}"
 
-        if self.single_config and self.build_type:
-            yield f"-DCMAKE_BUILD_TYPE:STRING={self.build_type}"
-
         for key, value in defines.items():
             if isinstance(value, bool):
                 str_value = "ON" if value else "OFF"
@@ -190,7 +195,7 @@ class CMaker:
         """
         generators = [g for g in args if g.startswith("-G")]
         if generators:
-            return generators[-1][2:]
+            return generators[-1][2:].strip()
         return self.env.get("CMAKE_GENERATOR", None)
 
     def configure(
@@ -206,6 +211,9 @@ class CMaker:
         if gen:
             self.single_config = gen == "Ninja" or "Makefiles" in gen
 
+        if self.single_config and self.build_type:
+            all_args.insert(2, f"-DCMAKE_BUILD_TYPE:STRING={self.build_type}")
+
         try:
             Run(env=self.env).live(self.cmake, *all_args)
         except subprocess.CalledProcessError:
