@@ -1,5 +1,6 @@
 import shutil
 import sys
+import sysconfig
 import zipfile
 from pathlib import Path
 
@@ -9,16 +10,14 @@ from scikit_build_core.build import build_wheel
 
 DIR = Path(__file__).parent.resolve()
 ABI_PKG = DIR / "packages/abi3_pyproject_ext"
+SYSCONFIGPLAT = sysconfig.get_platform()
 
 
-@pytest.mark.compile
-@pytest.mark.configure
+@pytest.mark.compile()
+@pytest.mark.configure()
 @pytest.mark.skipif(
-    sys.implementation.name == "pypy", reason="pypy does not support abi3"
-)
-@pytest.mark.skipif(
-    sys.platform.startswith("win"),
-    reason="abi3 is hard to target with FindPython on Windows",
+    sysconfig.get_platform().startswith(("msys", "mingw")),
+    reason="abi3 FindPython on MSYS/MinGW reports not found",
 )
 def test_abi3_wheel(tmp_path, monkeypatch, virtualenv):
     dist = tmp_path / "dist"
@@ -32,7 +31,14 @@ def test_abi3_wheel(tmp_path, monkeypatch, virtualenv):
     out = build_wheel(str(dist))
     (wheel,) = dist.glob("abi3_example-0.0.1-*.whl")
     assert wheel == dist / out
-    assert "-cp37-abi3-" in out
+    abi3 = sys.implementation.name == "cpython" and not sysconfig.get_config_var(
+        "Py_GIL_DISABLED"
+    )
+
+    if abi3:
+        assert "-cp37-abi3-" in out
+    else:
+        assert "-cp37-abi3-" not in out
 
     if sys.version_info >= (3, 8):
         with wheel.open("rb") as f:
@@ -44,12 +50,20 @@ def test_abi3_wheel(tmp_path, monkeypatch, virtualenv):
         file_names.remove("abi3_example-0.0.1.dist-info")
         (so_file,) = file_names
 
-        if sys.platform.startswith("win"):
-            assert so_file == "abi3_example.pyd"
+        if sysconfig.get_platform().startswith("win"):
+            if sys.implementation.name == "cpython":
+                assert so_file == "abi3_example.pyd"
+            else:
+                assert so_file.endswith(".pyd")
         elif sys.platform.startswith("cygwin"):
-            assert so_file == "abi3_example.abi3.dll"
-        else:
+            if abi3:
+                assert so_file == "abi3_example.abi3.dll"
+            else:
+                assert so_file != "abi3_example.abi3.dll"
+        elif abi3:
             assert so_file == "abi3_example.abi3.so"
+        else:
+            assert so_file != "abi3_example.abi3.so"
 
     virtualenv.install(wheel)
 
