@@ -4,10 +4,11 @@ import os
 import shutil
 import subprocess
 import sys
+import sysconfig
 from pathlib import Path
 
 import pytest
-from packaging.version import Version
+from packaging.specifiers import SpecifierSet
 
 from scikit_build_core.cmake import CMake, CMaker
 
@@ -21,7 +22,7 @@ has_ninja = shutil.which("ninja") is not None
 def prepare_env_or_skip() -> None:
     if (
         "CMAKE_GENERATOR" not in os.environ
-        and not sys.platform.startswith("win32")
+        and not sysconfig.get_platform().startswith("win")
         and not has_make
     ):
         if has_ninja:
@@ -38,7 +39,7 @@ def config(tmp_path_factory):
 
     build_dir = tmp_path / "build"
 
-    cmake = CMake.default_search(minimum_version=Version("3.15"))
+    cmake = CMake.default_search(version=SpecifierSet(">=3.15"))
     config = CMaker(
         cmake,
         source_dir=DIR / "packages/simple_pure",
@@ -54,8 +55,8 @@ def config(tmp_path_factory):
 
 
 # TODO: figure out why gmake is reporting no rule to make simple_pure.cpp
-@pytest.mark.compile
-@pytest.mark.configure
+@pytest.mark.compile()
+@pytest.mark.configure()
 @pytest.mark.xfail(
     sys.platform.startswith("cygwin"),
     strict=False,
@@ -79,8 +80,8 @@ def test_bin_in_config(config):
 
 
 # TODO: figure out why gmake is reporting no rule to make simple_pure.cpp
-@pytest.mark.compile
-@pytest.mark.configure
+@pytest.mark.compile()
+@pytest.mark.configure()
 @pytest.mark.xfail(
     sys.platform.startswith("cygwin"),
     strict=False,
@@ -100,13 +101,13 @@ def test_install(config):
     assert result.stdout == "0 one 2 three \n"
 
 
-@pytest.mark.configure
+@pytest.mark.configure()
 def test_variable_defined(tmp_path, capfd):
     prepare_env_or_skip()
 
     build_dir = tmp_path / "build"
 
-    cmake = CMake.default_search(minimum_version=Version("3.15"))
+    cmake = CMake.default_search(version=SpecifierSet(">=3.15"))
     config = CMaker(
         cmake,
         source_dir=DIR / "packages/simple_pure",
